@@ -317,7 +317,7 @@ sub html {
 
 		my $info = $self->{_info};
 
-		# The values in config are defaults which can be overriden by
+		# The values in config are defaults which can be overridden by
 		# the values in info, then the values in params
 		my $vals;
 		if(defined($self->{_config})) {
@@ -459,7 +459,7 @@ sub _debug {
 }
 
 sub obfuscate {
-	map { '&#' . ord($_) . ';' } split(//, shift);
+	return map { '&#' . ord($_) . ';' } split(//, shift);
 }
 
 sub _append_browser_type {
